============================================
 oslosphinx --- OpenStack Sphinx Extensions
============================================

oslosphinx contains the theme and extension support for Sphinx
documentation from the OpenStack project.

.. toctree::
   :maxdepth: 2

   usage
   check_blueprints
   contributing

Release Notes
=============

.. toctree::
   :maxdepth: 1

   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
